computational: Computational competencies survey responses from Global Health Engineering team members
Source:R/computational.R
computational.RdThis dataset contains survey responses about computational competencies collected from team members in preparation for the openwashdata conference in June 2025. The survey assessed experience with programming languages, development tools, and computational workflows.
Format
A tibble with 16 rows and 15 variables
- id
Unique identifier for each survey respondent.
- experience_programming_general
Self-reported experience with programming in general.
- experience_programming_r
Self-reported experience with programming in R.
- experience_programming_python
Self-reported experience with programming in Python.
- other_languages
Other programming languages or software the respondent has experience with (comma-separated).
- programming_confidence
Self-reported confidence in writing a program to find the largest number in a list.
- experience_git
Self-reported experience with using Git.
- experience_github
Self-reported experience with using GitHub.
- data_storage_format
Primary format used for data storage.
- document_writing_approach
Approach to writing narrative documents that include text and analysis.
- experience_ides
Self-reported experience with using Integrated Development Environments (IDEs).
- ides_used
IDEs that the respondent has used (comma-separated list).
- cli_usage
Self-reported usage of command-line interface on their operating system.
- llm_usage
Self-reported usage of Language Learning Models (LLMs) for various tasks.
- llm_tools_used
LLM tools or platforms used for research, ideation, writing, or coding (comma-separated list).